function cannon2(filename)
%cannon2(filename)
%
%  Description:
%
%    Calculate the distance of a projectile fired from a cannon by reading
%    the velocity and angle from a text input file and writing the distance
%    to a text output file.  Include air resistance.
%
%  Inputs:
%
%    filename = character string of an existing input file
%
%  Outputs:
%
%    The distance is written to a text output file named 'cannon.out'
%
%  Contact:
%
%    Bob Cochran
%    Applied CHT
%    rjc@heattransfer.org
%
%  History:
%
%    Who    Date   Version  Note
%    ---  -------- -------  -----------------------------------------------
%    RJC  05/24/17  0.1.0   Initial release.
%
%==========================================================================

% Math model parameters to be parsed from the input file

velocity    = NaN;
angle       = NaN;
drag        = NaN;

%--------------------------------------------------------------------------
% Open and parse the input file
%--------------------------------------------------------------------------

fileID   = fopen(filename,'r');
velocity = fscanf(fileID,'%f',1);
angle    = fscanf(fileID,'%f',1);
drag     = fscanf(fileID,'%f',1);
fclose(fileID);

%--------------------------------------------------------------------------
%  Calculate the distance of the cannon ball with air resistance
%--------------------------------------------------------------------------

gravity = 9.8;
x_0 = 0.0;
y_0 = 0.0;
v_x = cosd(angle)*velocity;
v_y = sind(angle)*velocity;
y = [x_0; y_0; v_x; v_y];
t = 0.0;
tend = (2*v_y)/gravity; % use no fluid resistance solution as maximum time
tspan=linspace(t, tend, 100);

% create an options variable
options = odeset('Events',@hitground);

[t, y, te, ye, ie] = ode45(@(t,y)motion(t, y, drag, gravity), tspan, y, options);

distance = ye(1);

%--------------------------------------------------------------------------
%  Open the output file and write the solution
%--------------------------------------------------------------------------

fileID = fopen('cannon.out','w');
fprintf(fileID,'  %16.9g\n',distance);
fclose(fileID);

end

function [dy] = motion(t, y, drag, gravity)

dy = zeros(4,1);

v_x      = y(3);
v_y      = y(4);
velocity = sqrt(v_x^2 + v_y^2);

dy(1) = v_x;                            % v_x = dx/dt
dy(2) = v_y;                            % v_y = dy/dt
dy(3) = -drag*velocity*v_x;             % a_x = d^2x/dt^2
dy(4) = -gravity - drag*velocity*v_y;   % a_y = d^2y/dt^2

end

function [value, isterminal, direction] = hitground(t,y)
% Locate the time when height passes through zero in a 
% decreasing direction and stop integration.
value = y(2);     % Detect height = 0
isterminal = 1;   % Stop the integration
direction = -1;   % Negative direction only
end
