function plotcentered( nsteps, params, response, data )
%plotcentered( nsteps, params, response, data )
%
%  Description:
%
%    Generate a centered parameter study plot for each of the response
%    variables.
%
%  Inputs:
%
%    nsteps   = number of steps in the study
%                 - see steps_per_variable in the Dakota input file
%    params   = cell vector of the parameter names
%    response = cell vector of the response variable names
%    data     = the params/response data from the tabular.dat file
%                  - use readtabular.m to parse the data
%
%  Contact:
%
%    Bob Cochran
%    Applied CHT
%    rjc@heattransfer.org
%
%  History:
%
%    Who    Date   Version  Note
%    ---  -------- -------  -----------------------------------------------
%    RJC  05/16/17  0.1.0   Initial release.
%    RJC  05/27/17  0.2.0   Added markers to the plot and also a second
%                           figure of reponse vs parameter for each pair
%
%==========================================================================

npar = length(params);     % number of parameters
nresp = length(response);  % number of repsonses
steps = [-nsteps:1:nsteps];

marker = {'o', '*', '+', '.', 'x', 's', 'd', '^', 'v', '>', '<', 'p', 'h'};

for i=1:nresp   % for each response in the data
  for j=1:npar  % for each parameter in the study
    row = 2 + (j-1)*2*nsteps;
    pdat(j,:) = data([row:row+nsteps-1, 1, row+nsteps:row+nsteps+nsteps-1], i+npar);
  end
  figure
  hold
  for k=1:npar
    h = plot(steps, pdat(k,:));
    h.Marker = marker{k};
  end
  xlabel('parameter step')
  ylabel(response{i})
  legend(params)
  title('Dakota Centered Parameter Study')
  grid on
  box on
end
hold off
% set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4 4],'Papersize',[4 4])
% print('cp_fig_1','-dpdf')
% print('cp_fig_1','-dpng', '-r100')

figure
pos = 1;
for i=1:nresp   % for each response in the study
  for j=1:npar  % for each parameter in the study
    row = 2 + (j-1)*2*nsteps;
    x = data([row:row+nsteps-1, 1, row+nsteps:row+nsteps+nsteps-1], j);
    y = data([row:row+nsteps-1, 1, row+nsteps:row+nsteps+nsteps-1], i+npar);
    subplot(nresp,npar,pos)
    plot(x,y)
    xlabel(params{j})
    ylabel(response{i})
    grid on
    pos = pos + 1;
  end
end
% set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4 4],'Papersize',[4 4])
% print('cp_fig_2','-dpdf')
% print('cp_fig_2','-dpng', '-r100')
